Class: Quickfix::DateTime
- Inherits:
-
Object
- Object
- Quickfix::DateTime
- Defined in:
- ext/quickfix/QuickfixRuby.cpp
Class Method Summary collapse
- .convertToNanos(*args) ⇒ Object
- .fromLocalTimeT(*args, self) ⇒ Object
- .fromTm(*args, self) ⇒ Object
- .fromUtcTimeT(*args, self) ⇒ Object
- .julianDate(*args) ⇒ Object
- .makeHMS(*args) ⇒ Object
- .nowLocal(*args) ⇒ Object
- .nowUtc(*args) ⇒ Object
Instance Method Summary collapse
- #clearDate(*args) ⇒ Object
- #clearTime(*args) ⇒ Object
- #getDate(*args) ⇒ Object
- #getDay(*args) ⇒ Object
- #getFraction(*args) ⇒ Object
- #getHour(*args) ⇒ Object
- #getJulianDate(*args) ⇒ Object
- #getMicrosecond(*args) ⇒ Object
- #getMillisecond(*args) ⇒ Object
- #getMinute(*args) ⇒ Object
- #getMonth(*args) ⇒ Object
- #getNanosecond(*args) ⇒ Object
- #getSecond(*args) ⇒ Object
- #getTimeT(*args) ⇒ Object
- #getTmUtc(*args) ⇒ Object
- #getWeekDay(*args) ⇒ Object
- #getYear(*args) ⇒ Object
- #initialize(*args, self) ⇒ Object constructor
- #m_date(*args) ⇒ Object
- #m_date=(*args) ⇒ Object
- #m_time(*args) ⇒ Object
- #m_time=(*args) ⇒ Object
- #set(*args, self) ⇒ Object
- #setFraction(*args) ⇒ Object
- #setHMS(*args, self) ⇒ Object
- #setHour(*args) ⇒ Object
- #setMicrosecond(*args) ⇒ Object
- #setMillisecond(*args) ⇒ Object
- #setMinute(*args) ⇒ Object
- #setNanosecond(*args) ⇒ Object
- #setSecond(*args) ⇒ Object
- #setYMD(*args) ⇒ Object
Constructor Details
#initialize(*args, self) ⇒ Object
18565 18566 18567 18568 18569 18570 18571 18572 18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 18616 18617 18618 18619 18620 18621 18622 18623 18624 18625 18626 18627 18628 18629 18630 18631 18632 18633 18634 18635 18636 18637 18638 18639 18640 18641 18642 18643 18644 18645 18646 18647 18648 18649 18650 18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 18661 18662 18663 18664 18665 18666 18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 18679 18680 18681 18682 18683 18684 18685 18686 18687 18688 18689 18690 18691 18692 18693 18694 18695 18696 18697 18698 18699 18700 18701 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18565
SWIGINTERN VALUE _wrap_new_DateTime(int nargs, VALUE *args, VALUE self) {
int argc;
VALUE argv[8];
int ii;
argc = nargs;
if (argc > 8) SWIG_fail;
for (ii = 0; (ii < argc); ++ii) {
argv[ii] = args[ii];
}
if (argc == 0) {
return _wrap_new_DateTime__SWIG_0(nargs, args, self);
}
if (argc == 2) {
int _v = 0;
{
int res = SWIG_AsVal_int(argv[0], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_long_SS_long(argv[1], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
return _wrap_new_DateTime__SWIG_1(nargs, args, self);
}
}
}
if (argc == 7) {
int _v = 0;
{
int res = SWIG_AsVal_int(argv[0], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[1], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[2], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[3], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[4], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[5], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[6], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
return _wrap_new_DateTime__SWIG_2(nargs, args, self);
}
}
}
}
}
}
}
}
if (argc == 8) {
int _v = 0;
{
int res = SWIG_AsVal_int(argv[0], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[1], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[2], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[3], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[4], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[5], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[6], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[7], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
return _wrap_new_DateTime__SWIG_3(nargs, args, self);
}
}
}
}
}
}
}
}
}
fail:
Ruby_Format_OverloadedError( argc, 8, "DateTime.new",
" DateTime.new()\n"
" DateTime.new(int date, int64_t time)\n"
" DateTime.new(int year, int month, int day, int hour, int minute, int second, int millis)\n"
" DateTime.new(int year, int month, int day, int hour, int minute, int second, int fraction, int precision)\n");
return Qnil;
}
|
Class Method Details
.convertToNanos(*args) ⇒ Object
20029 20030 20031 20032 20033 20034 20035 20036 20037 20038 20039 20040 20041 20042 20043 20044 20045 20046 20047 20048 20049 20050 20051 20052 20053 20054 20055 20056 20057 20058 20059 20060 20061 20062 20063 20064 20065 20066 20067 20068 20069 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 20029
SWIGINTERN VALUE
_wrap_DateTime_convertToNanos(int argc, VALUE *argv, VALUE self) {
int arg1 ;
int arg2 ;
int val1 ;
int ecode1 = 0 ;
int val2 ;
int ecode2 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 2) || (argc > 2)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
}
ecode1 = SWIG_AsVal_int(argv[0], &val1);
if (!SWIG_IsOK(ecode1)) {
SWIG_exception_fail(SWIG_ArgError(ecode1), Ruby_Format_TypeError( "", "int","FIX::DateTime::convertToNanos", 1, argv[0] ));
}
arg1 = static_cast< int >(val1);
ecode2 = SWIG_AsVal_int(argv[1], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","FIX::DateTime::convertToNanos", 2, argv[1] ));
}
arg2 = static_cast< int >(val2);
{
if(tryRubyException([&]() mutable
{
result = (int)FIX::DateTime::convertToNanos(arg1,arg2);
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
.fromLocalTimeT(*args, self) ⇒ Object
20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 20522 20523 20524 20525 20526 20527 20528 20529 20530 20531 20532 20533 20534 20535 20536 20537 20538 20539 20540 20541 20542 20543 20544 20545 20546 20547 20548 20549 20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 20503
SWIGINTERN VALUE _wrap_DateTime_fromLocalTimeT(int nargs, VALUE *args, VALUE self) {
int argc;
VALUE argv[3];
int ii;
argc = nargs;
if (argc > 3) SWIG_fail;
for (ii = 0; (ii < argc); ++ii) {
argv[ii] = args[ii];
}
if (argc == 1) {
int _v = 0;
{
_v = (NIL_P(argv[0]) || TYPE(rb_funcall(argv[0], rb_intern("respond_to?"), 1, ID2SYM(rb_intern("tv_sec")))) == T_TRUE);
}
if (_v) {
return _wrap_DateTime_fromLocalTimeT__SWIG_1(nargs, args, self);
}
}
if (argc == 2) {
int _v = 0;
{
_v = (NIL_P(argv[0]) || TYPE(rb_funcall(argv[0], rb_intern("respond_to?"), 1, ID2SYM(rb_intern("tv_sec")))) == T_TRUE);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[1], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
return _wrap_DateTime_fromLocalTimeT__SWIG_0(nargs, args, self);
}
}
}
if (argc == 3) {
int _v = 0;
{
_v = (NIL_P(argv[0]) || TYPE(rb_funcall(argv[0], rb_intern("respond_to?"), 1, ID2SYM(rb_intern("tv_sec")))) == T_TRUE);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[1], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[2], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
return _wrap_DateTime_fromLocalTimeT__SWIG_2(nargs, args, self);
}
}
}
}
fail:
Ruby_Format_OverloadedError( argc, 3, "DateTime.fromLocalTimeT",
" FIX::DateTime DateTime.fromLocalTimeT(time_t t, int millis)\n"
" FIX::DateTime DateTime.fromLocalTimeT(time_t t)\n"
" FIX::DateTime DateTime.fromLocalTimeT(time_t t, int fraction, int precision)\n");
return Qnil;
}
|
.fromTm(*args, self) ⇒ Object
20707 20708 20709 20710 20711 20712 20713 20714 20715 20716 20717 20718 20719 20720 20721 20722 20723 20724 20725 20726 20727 20728 20729 20730 20731 20732 20733 20734 20735 20736 20737 20738 20739 20740 20741 20742 20743 20744 20745 20746 20747 20748 20749 20750 20751 20752 20753 20754 20755 20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 20707
SWIGINTERN VALUE _wrap_DateTime_fromTm(int nargs, VALUE *args, VALUE self) {
int argc;
VALUE argv[3];
int ii;
argc = nargs;
if (argc > 3) SWIG_fail;
for (ii = 0; (ii < argc); ++ii) {
argv[ii] = args[ii];
}
if (argc == 1) {
int _v = 0;
void *vptr = 0;
int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_tm, SWIG_POINTER_NO_NULL);
_v = SWIG_CheckState(res);
if (_v) {
return _wrap_DateTime_fromTm__SWIG_1(nargs, args, self);
}
}
if (argc == 2) {
int _v = 0;
void *vptr = 0;
int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_tm, SWIG_POINTER_NO_NULL);
_v = SWIG_CheckState(res);
if (_v) {
{
int res = SWIG_AsVal_int(argv[1], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
return _wrap_DateTime_fromTm__SWIG_0(nargs, args, self);
}
}
}
if (argc == 3) {
int _v = 0;
void *vptr = 0;
int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_tm, SWIG_POINTER_NO_NULL);
_v = SWIG_CheckState(res);
if (_v) {
{
int res = SWIG_AsVal_int(argv[1], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[2], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
return _wrap_DateTime_fromTm__SWIG_2(nargs, args, self);
}
}
}
}
fail:
Ruby_Format_OverloadedError( argc, 3, "DateTime.fromTm",
" FIX::DateTime DateTime.fromTm(tm const &tm, int millis)\n"
" FIX::DateTime DateTime.fromTm(tm const &tm)\n"
" FIX::DateTime DateTime.fromTm(tm const &tm, int fraction, int precision)\n");
return Qnil;
}
|
.fromUtcTimeT(*args, self) ⇒ Object
20387 20388 20389 20390 20391 20392 20393 20394 20395 20396 20397 20398 20399 20400 20401 20402 20403 20404 20405 20406 20407 20408 20409 20410 20411 20412 20413 20414 20415 20416 20417 20418 20419 20420 20421 20422 20423 20424 20425 20426 20427 20428 20429 20430 20431 20432 20433 20434 20435 20436 20437 20438 20439 20440 20441 20442 20443 20444 20445 20446 20447 20448 20449 20450 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 20387
SWIGINTERN VALUE _wrap_DateTime_fromUtcTimeT(int nargs, VALUE *args, VALUE self) {
int argc;
VALUE argv[3];
int ii;
argc = nargs;
if (argc > 3) SWIG_fail;
for (ii = 0; (ii < argc); ++ii) {
argv[ii] = args[ii];
}
if (argc == 1) {
int _v = 0;
{
_v = (NIL_P(argv[0]) || TYPE(rb_funcall(argv[0], rb_intern("respond_to?"), 1, ID2SYM(rb_intern("tv_sec")))) == T_TRUE);
}
if (_v) {
return _wrap_DateTime_fromUtcTimeT__SWIG_1(nargs, args, self);
}
}
if (argc == 2) {
int _v = 0;
{
_v = (NIL_P(argv[0]) || TYPE(rb_funcall(argv[0], rb_intern("respond_to?"), 1, ID2SYM(rb_intern("tv_sec")))) == T_TRUE);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[1], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
return _wrap_DateTime_fromUtcTimeT__SWIG_0(nargs, args, self);
}
}
}
if (argc == 3) {
int _v = 0;
{
_v = (NIL_P(argv[0]) || TYPE(rb_funcall(argv[0], rb_intern("respond_to?"), 1, ID2SYM(rb_intern("tv_sec")))) == T_TRUE);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[1], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[2], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
return _wrap_DateTime_fromUtcTimeT__SWIG_2(nargs, args, self);
}
}
}
}
fail:
Ruby_Format_OverloadedError( argc, 3, "DateTime.fromUtcTimeT",
" FIX::DateTime DateTime.fromUtcTimeT(time_t t, int millis)\n"
" FIX::DateTime DateTime.fromUtcTimeT(time_t t)\n"
" FIX::DateTime DateTime.fromUtcTimeT(time_t t, int fraction, int precision)\n");
return Qnil;
}
|
.julianDate(*args) ⇒ Object
20773 20774 20775 20776 20777 20778 20779 20780 20781 20782 20783 20784 20785 20786 20787 20788 20789 20790 20791 20792 20793 20794 20795 20796 20797 20798 20799 20800 20801 20802 20803 20804 20805 20806 20807 20808 20809 20810 20811 20812 20813 20814 20815 20816 20817 20818 20819 20820 20821 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 20773
SWIGINTERN VALUE
_wrap_DateTime_julianDate(int argc, VALUE *argv, VALUE self) {
int arg1 ;
int arg2 ;
int arg3 ;
int val1 ;
int ecode1 = 0 ;
int val2 ;
int ecode2 = 0 ;
int val3 ;
int ecode3 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 3) || (argc > 3)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 3)",argc); SWIG_fail;
}
ecode1 = SWIG_AsVal_int(argv[0], &val1);
if (!SWIG_IsOK(ecode1)) {
SWIG_exception_fail(SWIG_ArgError(ecode1), Ruby_Format_TypeError( "", "int","FIX::DateTime::julianDate", 1, argv[0] ));
}
arg1 = static_cast< int >(val1);
ecode2 = SWIG_AsVal_int(argv[1], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","FIX::DateTime::julianDate", 2, argv[1] ));
}
arg2 = static_cast< int >(val2);
ecode3 = SWIG_AsVal_int(argv[2], &val3);
if (!SWIG_IsOK(ecode3)) {
SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "int","FIX::DateTime::julianDate", 3, argv[2] ));
}
arg3 = static_cast< int >(val3);
{
if(tryRubyException([&]() mutable
{
result = (int)FIX::DateTime::julianDate(arg1,arg2,arg3);
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
.makeHMS(*args) ⇒ Object
20072 20073 20074 20075 20076 20077 20078 20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 20096 20097 20098 20099 20100 20101 20102 20103 20104 20105 20106 20107 20108 20109 20110 20111 20112 20113 20114 20115 20116 20117 20118 20119 20120 20121 20122 20123 20124 20125 20126 20127 20128 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 20072
SWIGINTERN VALUE
_wrap_DateTime_makeHMS(int argc, VALUE *argv, VALUE self) {
int arg1 ;
int arg2 ;
int arg3 ;
int arg4 ;
int val1 ;
int ecode1 = 0 ;
int val2 ;
int ecode2 = 0 ;
int val3 ;
int ecode3 = 0 ;
int val4 ;
int ecode4 = 0 ;
int64_t result;
VALUE vresult = Qnil;
if ((argc < 4) || (argc > 4)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 4)",argc); SWIG_fail;
}
ecode1 = SWIG_AsVal_int(argv[0], &val1);
if (!SWIG_IsOK(ecode1)) {
SWIG_exception_fail(SWIG_ArgError(ecode1), Ruby_Format_TypeError( "", "int","FIX::DateTime::makeHMS", 1, argv[0] ));
}
arg1 = static_cast< int >(val1);
ecode2 = SWIG_AsVal_int(argv[1], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","FIX::DateTime::makeHMS", 2, argv[1] ));
}
arg2 = static_cast< int >(val2);
ecode3 = SWIG_AsVal_int(argv[2], &val3);
if (!SWIG_IsOK(ecode3)) {
SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "int","FIX::DateTime::makeHMS", 3, argv[2] ));
}
arg3 = static_cast< int >(val3);
ecode4 = SWIG_AsVal_int(argv[3], &val4);
if (!SWIG_IsOK(ecode4)) {
SWIG_exception_fail(SWIG_ArgError(ecode4), Ruby_Format_TypeError( "", "int","FIX::DateTime::makeHMS", 4, argv[3] ));
}
arg4 = static_cast< int >(val4);
{
if(tryRubyException([&]() mutable
{
result = (int64_t)FIX::DateTime::makeHMS(arg1,arg2,arg3,arg4);
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_long_SS_long(static_cast< long long >(result));
return vresult;
fail:
return Qnil;
}
|
.nowLocal(*args) ⇒ Object
20158 20159 20160 20161 20162 20163 20164 20165 20166 20167 20168 20169 20170 20171 20172 20173 20174 20175 20176 20177 20178 20179 20180 20181 20182 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 20158
SWIGINTERN VALUE
_wrap_DateTime_nowLocal(int argc, VALUE *argv, VALUE self) {
FIX::DateTime result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
{
if(tryRubyException([&]() mutable
{
result = FIX::DateTime::nowLocal();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_NewPointerObj((new FIX::DateTime(result)), SWIGTYPE_p_FIX__DateTime, SWIG_POINTER_OWN | 0 );
return vresult;
fail:
return Qnil;
}
|
.nowUtc(*args) ⇒ Object
20131 20132 20133 20134 20135 20136 20137 20138 20139 20140 20141 20142 20143 20144 20145 20146 20147 20148 20149 20150 20151 20152 20153 20154 20155 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 20131
SWIGINTERN VALUE
_wrap_DateTime_nowUtc(int argc, VALUE *argv, VALUE self) {
FIX::DateTime result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
{
if(tryRubyException([&]() mutable
{
result = FIX::DateTime::nowUtc();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_NewPointerObj((new FIX::DateTime(result)), SWIGTYPE_p_FIX__DateTime, SWIG_POINTER_OWN | 0 );
return vresult;
fail:
return Qnil;
}
|
Instance Method Details
#clearDate(*args) ⇒ Object
19818 19819 19820 19821 19822 19823 19824 19825 19826 19827 19828 19829 19830 19831 19832 19833 19834 19835 19836 19837 19838 19839 19840 19841 19842 19843 19844 19845 19846 19847 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19818
SWIGINTERN VALUE
_wrap_DateTime_clearDate(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","clearDate", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
(arg1)->clearDate();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
return Qnil;
fail:
return Qnil;
}
|
#clearTime(*args) ⇒ Object
19850 19851 19852 19853 19854 19855 19856 19857 19858 19859 19860 19861 19862 19863 19864 19865 19866 19867 19868 19869 19870 19871 19872 19873 19874 19875 19876 19877 19878 19879 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19850
SWIGINTERN VALUE
_wrap_DateTime_clearTime(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","clearTime", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
(arg1)->clearTime();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
return Qnil;
fail:
return Qnil;
}
|
#getDate(*args) ⇒ Object
18815 18816 18817 18818 18819 18820 18821 18822 18823 18824 18825 18826 18827 18828 18829 18830 18831 18832 18833 18834 18835 18836 18837 18838 18839 18840 18841 18842 18843 18844 18845 18846 18847 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18815
SWIGINTERN VALUE
_wrap_DateTime_getDate(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getDate", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = (int)((FIX::DateTime const *)arg1)->getDate();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#getDay(*args) ⇒ Object
18780 18781 18782 18783 18784 18785 18786 18787 18788 18789 18790 18791 18792 18793 18794 18795 18796 18797 18798 18799 18800 18801 18802 18803 18804 18805 18806 18807 18808 18809 18810 18811 18812 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18780
SWIGINTERN VALUE
_wrap_DateTime_getDay(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getDay", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = (int)((FIX::DateTime const *)arg1)->getDay();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#getFraction(*args) ⇒ Object
19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 19122 19123 19124 19125 19126 19127 19128 19129 19130 19131 19132 19133 19134 19135 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19095
SWIGINTERN VALUE
_wrap_DateTime_getFraction(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
int arg2 ;
void *argp1 = 0 ;
int res1 = 0 ;
int val2 ;
int ecode2 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 1) || (argc > 1)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getFraction", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
ecode2 = SWIG_AsVal_int(argv[0], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","getFraction", 2, argv[0] ));
}
arg2 = static_cast< int >(val2);
{
if(tryRubyException([&]() mutable
{
result = (int)((FIX::DateTime const *)arg1)->getFraction(arg2);
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#getHour(*args) ⇒ Object
18885 18886 18887 18888 18889 18890 18891 18892 18893 18894 18895 18896 18897 18898 18899 18900 18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 18912 18913 18914 18915 18916 18917 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18885
SWIGINTERN VALUE
_wrap_DateTime_getHour(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getHour", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = (int)((FIX::DateTime const *)arg1)->getHour();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#getJulianDate(*args) ⇒ Object
18850 18851 18852 18853 18854 18855 18856 18857 18858 18859 18860 18861 18862 18863 18864 18865 18866 18867 18868 18869 18870 18871 18872 18873 18874 18875 18876 18877 18878 18879 18880 18881 18882 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18850
SWIGINTERN VALUE
_wrap_DateTime_getJulianDate(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getJulianDate", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = (int)((FIX::DateTime const *)arg1)->getJulianDate();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#getMicrosecond(*args) ⇒ Object
19025 19026 19027 19028 19029 19030 19031 19032 19033 19034 19035 19036 19037 19038 19039 19040 19041 19042 19043 19044 19045 19046 19047 19048 19049 19050 19051 19052 19053 19054 19055 19056 19057 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19025
SWIGINTERN VALUE
_wrap_DateTime_getMicrosecond(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getMicrosecond", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = (int)((FIX::DateTime const *)arg1)->getMicrosecond();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#getMillisecond(*args) ⇒ Object
18990 18991 18992 18993 18994 18995 18996 18997 18998 18999 19000 19001 19002 19003 19004 19005 19006 19007 19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18990
SWIGINTERN VALUE
_wrap_DateTime_getMillisecond(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getMillisecond", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = (int)((FIX::DateTime const *)arg1)->getMillisecond();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#getMinute(*args) ⇒ Object
18920 18921 18922 18923 18924 18925 18926 18927 18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 18946 18947 18948 18949 18950 18951 18952 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18920
SWIGINTERN VALUE
_wrap_DateTime_getMinute(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getMinute", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = (int)((FIX::DateTime const *)arg1)->getMinute();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#getMonth(*args) ⇒ Object
18745 18746 18747 18748 18749 18750 18751 18752 18753 18754 18755 18756 18757 18758 18759 18760 18761 18762 18763 18764 18765 18766 18767 18768 18769 18770 18771 18772 18773 18774 18775 18776 18777 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18745
SWIGINTERN VALUE
_wrap_DateTime_getMonth(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getMonth", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = (int)((FIX::DateTime const *)arg1)->getMonth();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#getNanosecond(*args) ⇒ Object
19060 19061 19062 19063 19064 19065 19066 19067 19068 19069 19070 19071 19072 19073 19074 19075 19076 19077 19078 19079 19080 19081 19082 19083 19084 19085 19086 19087 19088 19089 19090 19091 19092 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19060
SWIGINTERN VALUE
_wrap_DateTime_getNanosecond(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
unsigned int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getNanosecond", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = (unsigned int)((FIX::DateTime const *)arg1)->getNanosecond();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
return vresult;
fail:
return Qnil;
}
|
#getSecond(*args) ⇒ Object
18955 18956 18957 18958 18959 18960 18961 18962 18963 18964 18965 18966 18967 18968 18969 18970 18971 18972 18973 18974 18975 18976 18977 18978 18979 18980 18981 18982 18983 18984 18985 18986 18987 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18955
SWIGINTERN VALUE
_wrap_DateTime_getSecond(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getSecond", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = (int)((FIX::DateTime const *)arg1)->getSecond();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#getTimeT(*args) ⇒ Object
19173 19174 19175 19176 19177 19178 19179 19180 19181 19182 19183 19184 19185 19186 19187 19188 19189 19190 19191 19192 19193 19194 19195 19196 19197 19198 19199 19200 19201 19202 19203 19204 19205 19206 19207 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19173
SWIGINTERN VALUE
_wrap_DateTime_getTimeT(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
time_t result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getTimeT", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = ((FIX::DateTime const *)arg1)->getTimeT();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
{
vresult = rb_time_new(result, 0);
}
return vresult;
fail:
return Qnil;
}
|
#getTmUtc(*args) ⇒ Object
19210 19211 19212 19213 19214 19215 19216 19217 19218 19219 19220 19221 19222 19223 19224 19225 19226 19227 19228 19229 19230 19231 19232 19233 19234 19235 19236 19237 19238 19239 19240 19241 19242 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19210
SWIGINTERN VALUE
_wrap_DateTime_getTmUtc(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
tm result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getTmUtc", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = ((FIX::DateTime const *)arg1)->getTmUtc();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_NewPointerObj((new tm(result)), SWIGTYPE_p_tm, SWIG_POINTER_OWN | 0 );
return vresult;
fail:
return Qnil;
}
|
#getWeekDay(*args) ⇒ Object
19138 19139 19140 19141 19142 19143 19144 19145 19146 19147 19148 19149 19150 19151 19152 19153 19154 19155 19156 19157 19158 19159 19160 19161 19162 19163 19164 19165 19166 19167 19168 19169 19170 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19138
SWIGINTERN VALUE
_wrap_DateTime_getWeekDay(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getWeekDay", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = (int)((FIX::DateTime const *)arg1)->getWeekDay();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#getYear(*args) ⇒ Object
18710 18711 18712 18713 18714 18715 18716 18717 18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 18728 18729 18730 18731 18732 18733 18734 18735 18736 18737 18738 18739 18740 18741 18742 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18710
SWIGINTERN VALUE
_wrap_DateTime_getYear(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime const *","getYear", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
{
if(tryRubyException([&]() mutable
{
result = (int)((FIX::DateTime const *)arg1)->getYear();
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#m_date(*args) ⇒ Object
18229 18230 18231 18232 18233 18234 18235 18236 18237 18238 18239 18240 18241 18242 18243 18244 18245 18246 18247 18248 18249 18250 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18229
SWIGINTERN VALUE
_wrap_DateTime_m_date_get(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","m_date", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
result = (int) ((arg1)->m_date);
vresult = SWIG_From_int(static_cast< int >(result));
return vresult;
fail:
return Qnil;
}
|
#m_date=(*args) ⇒ Object
18200 18201 18202 18203 18204 18205 18206 18207 18208 18209 18210 18211 18212 18213 18214 18215 18216 18217 18218 18219 18220 18221 18222 18223 18224 18225 18226 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18200
SWIGINTERN VALUE
_wrap_DateTime_m_date_set(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
int arg2 ;
void *argp1 = 0 ;
int res1 = 0 ;
int val2 ;
int ecode2 = 0 ;
if ((argc < 1) || (argc > 1)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","m_date", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
ecode2 = SWIG_AsVal_int(argv[0], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","m_date", 2, argv[0] ));
}
arg2 = static_cast< int >(val2);
if (arg1) (arg1)->m_date = arg2;
return Qnil;
fail:
return Qnil;
}
|
#m_time(*args) ⇒ Object
18282 18283 18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18282
SWIGINTERN VALUE
_wrap_DateTime_m_time_get(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
void *argp1 = 0 ;
int res1 = 0 ;
int64_t result;
VALUE vresult = Qnil;
if ((argc < 0) || (argc > 0)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","m_time", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
result = (int64_t) ((arg1)->m_time);
vresult = SWIG_From_long_SS_long(static_cast< long long >(result));
return vresult;
fail:
return Qnil;
}
|
#m_time=(*args) ⇒ Object
18253 18254 18255 18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 18279 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 18253
SWIGINTERN VALUE
_wrap_DateTime_m_time_set(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
int64_t arg2 ;
void *argp1 = 0 ;
int res1 = 0 ;
long long val2 ;
int ecode2 = 0 ;
if ((argc < 1) || (argc > 1)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","m_time", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
ecode2 = SWIG_AsVal_long_SS_long(argv[0], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int64_t","m_time", 2, argv[0] ));
}
arg2 = static_cast< int64_t >(val2);
if (arg1) (arg1)->m_time = arg2;
return Qnil;
fail:
return Qnil;
}
|
#set(*args, self) ⇒ Object
19973 19974 19975 19976 19977 19978 19979 19980 19981 19982 19983 19984 19985 19986 19987 19988 19989 19990 19991 19992 19993 19994 19995 19996 19997 19998 19999 20000 20001 20002 20003 20004 20005 20006 20007 20008 20009 20010 20011 20012 20013 20014 20015 20016 20017 20018 20019 20020 20021 20022 20023 20024 20025 20026 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19973
SWIGINTERN VALUE _wrap_DateTime_set(int nargs, VALUE *args, VALUE self) {
int argc;
VALUE argv[4];
int ii;
argc = nargs + 1;
argv[0] = self;
if (argc > 4) SWIG_fail;
for (ii = 1; (ii < argc); ++ii) {
argv[ii] = args[ii-1];
}
if (argc == 2) {
int _v = 0;
void *vptr = 0;
int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__DateTime, 0);
_v = SWIG_CheckState(res);
if (_v) {
void *vptr = 0;
int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_FIX__DateTime, SWIG_POINTER_NO_NULL);
_v = SWIG_CheckState(res);
if (_v) {
return _wrap_DateTime_set__SWIG_1(nargs, args, self);
}
}
}
if (argc == 3) {
int _v = 0;
void *vptr = 0;
int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__DateTime, 0);
_v = SWIG_CheckState(res);
if (_v) {
{
int res = SWIG_AsVal_int(argv[1], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_long_SS_long(argv[2], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
return _wrap_DateTime_set__SWIG_0(nargs, args, self);
}
}
}
}
fail:
Ruby_Format_OverloadedError( argc, 4, "DateTime.set",
" void DateTime.set(int date, int64_t time)\n"
" void DateTime.set(FIX::DateTime const &other)\n");
return Qnil;
}
|
#setFraction(*args) ⇒ Object
19770 19771 19772 19773 19774 19775 19776 19777 19778 19779 19780 19781 19782 19783 19784 19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 19810 19811 19812 19813 19814 19815 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19770
SWIGINTERN VALUE
_wrap_DateTime_setFraction(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
int arg2 ;
int arg3 ;
void *argp1 = 0 ;
int res1 = 0 ;
int val2 ;
int ecode2 = 0 ;
int val3 ;
int ecode3 = 0 ;
if ((argc < 2) || (argc > 2)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","setFraction", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
ecode2 = SWIG_AsVal_int(argv[0], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","setFraction", 2, argv[0] ));
}
arg2 = static_cast< int >(val2);
ecode3 = SWIG_AsVal_int(argv[1], &val3);
if (!SWIG_IsOK(ecode3)) {
SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "int","setFraction", 3, argv[1] ));
}
arg3 = static_cast< int >(val3);
{
if(tryRubyException([&]() mutable
{
(arg1)->setFraction(arg2,arg3);
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
return Qnil;
fail:
return Qnil;
}
|
#setHMS(*args, self) ⇒ Object
19437 19438 19439 19440 19441 19442 19443 19444 19445 19446 19447 19448 19449 19450 19451 19452 19453 19454 19455 19456 19457 19458 19459 19460 19461 19462 19463 19464 19465 19466 19467 19468 19469 19470 19471 19472 19473 19474 19475 19476 19477 19478 19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 19503 19504 19505 19506 19507 19508 19509 19510 19511 19512 19513 19514 19515 19516 19517 19518 19519 19520 19521 19522 19523 19524 19525 19526 19527 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19437
SWIGINTERN VALUE _wrap_DateTime_setHMS(int nargs, VALUE *args, VALUE self) {
int argc;
VALUE argv[7];
int ii;
argc = nargs + 1;
argv[0] = self;
if (argc > 7) SWIG_fail;
for (ii = 1; (ii < argc); ++ii) {
argv[ii] = args[ii-1];
}
if (argc == 5) {
int _v = 0;
void *vptr = 0;
int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__DateTime, 0);
_v = SWIG_CheckState(res);
if (_v) {
{
int res = SWIG_AsVal_int(argv[1], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[2], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[3], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[4], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
return _wrap_DateTime_setHMS__SWIG_0(nargs, args, self);
}
}
}
}
}
}
if (argc == 6) {
int _v = 0;
void *vptr = 0;
int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__DateTime, 0);
_v = SWIG_CheckState(res);
if (_v) {
{
int res = SWIG_AsVal_int(argv[1], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[2], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[3], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[4], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
{
int res = SWIG_AsVal_int(argv[5], NULL);
_v = SWIG_CheckState(res);
}
if (_v) {
return _wrap_DateTime_setHMS__SWIG_1(nargs, args, self);
}
}
}
}
}
}
}
fail:
Ruby_Format_OverloadedError( argc, 7, "DateTime.setHMS",
" void DateTime.setHMS(int hour, int minute, int second, int millis)\n"
" void DateTime.setHMS(int hour, int minute, int second, int fraction, int precision)\n");
return Qnil;
}
|
#setHour(*args) ⇒ Object
19530 19531 19532 19533 19534 19535 19536 19537 19538 19539 19540 19541 19542 19543 19544 19545 19546 19547 19548 19549 19550 19551 19552 19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19530
SWIGINTERN VALUE
_wrap_DateTime_setHour(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
int arg2 ;
void *argp1 = 0 ;
int res1 = 0 ;
int val2 ;
int ecode2 = 0 ;
if ((argc < 1) || (argc > 1)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","setHour", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
ecode2 = SWIG_AsVal_int(argv[0], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","setHour", 2, argv[0] ));
}
arg2 = static_cast< int >(val2);
{
if(tryRubyException([&]() mutable
{
(arg1)->setHour(arg2);
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
return Qnil;
fail:
return Qnil;
}
|
#setMicrosecond(*args) ⇒ Object
19690 19691 19692 19693 19694 19695 19696 19697 19698 19699 19700 19701 19702 19703 19704 19705 19706 19707 19708 19709 19710 19711 19712 19713 19714 19715 19716 19717 19718 19719 19720 19721 19722 19723 19724 19725 19726 19727 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19690
SWIGINTERN VALUE
_wrap_DateTime_setMicrosecond(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
int arg2 ;
void *argp1 = 0 ;
int res1 = 0 ;
int val2 ;
int ecode2 = 0 ;
if ((argc < 1) || (argc > 1)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","setMicrosecond", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
ecode2 = SWIG_AsVal_int(argv[0], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","setMicrosecond", 2, argv[0] ));
}
arg2 = static_cast< int >(val2);
{
if(tryRubyException([&]() mutable
{
(arg1)->setMicrosecond(arg2);
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
return Qnil;
fail:
return Qnil;
}
|
#setMillisecond(*args) ⇒ Object
19650 19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19650
SWIGINTERN VALUE
_wrap_DateTime_setMillisecond(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
int arg2 ;
void *argp1 = 0 ;
int res1 = 0 ;
int val2 ;
int ecode2 = 0 ;
if ((argc < 1) || (argc > 1)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","setMillisecond", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
ecode2 = SWIG_AsVal_int(argv[0], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","setMillisecond", 2, argv[0] ));
}
arg2 = static_cast< int >(val2);
{
if(tryRubyException([&]() mutable
{
(arg1)->setMillisecond(arg2);
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
return Qnil;
fail:
return Qnil;
}
|
#setMinute(*args) ⇒ Object
19570 19571 19572 19573 19574 19575 19576 19577 19578 19579 19580 19581 19582 19583 19584 19585 19586 19587 19588 19589 19590 19591 19592 19593 19594 19595 19596 19597 19598 19599 19600 19601 19602 19603 19604 19605 19606 19607 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19570
SWIGINTERN VALUE
_wrap_DateTime_setMinute(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
int arg2 ;
void *argp1 = 0 ;
int res1 = 0 ;
int val2 ;
int ecode2 = 0 ;
if ((argc < 1) || (argc > 1)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","setMinute", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
ecode2 = SWIG_AsVal_int(argv[0], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","setMinute", 2, argv[0] ));
}
arg2 = static_cast< int >(val2);
{
if(tryRubyException([&]() mutable
{
(arg1)->setMinute(arg2);
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
return Qnil;
fail:
return Qnil;
}
|
#setNanosecond(*args) ⇒ Object
19730 19731 19732 19733 19734 19735 19736 19737 19738 19739 19740 19741 19742 19743 19744 19745 19746 19747 19748 19749 19750 19751 19752 19753 19754 19755 19756 19757 19758 19759 19760 19761 19762 19763 19764 19765 19766 19767 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19730
SWIGINTERN VALUE
_wrap_DateTime_setNanosecond(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
int arg2 ;
void *argp1 = 0 ;
int res1 = 0 ;
int val2 ;
int ecode2 = 0 ;
if ((argc < 1) || (argc > 1)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","setNanosecond", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
ecode2 = SWIG_AsVal_int(argv[0], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","setNanosecond", 2, argv[0] ));
}
arg2 = static_cast< int >(val2);
{
if(tryRubyException([&]() mutable
{
(arg1)->setNanosecond(arg2);
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
return Qnil;
fail:
return Qnil;
}
|
#setSecond(*args) ⇒ Object
19610 19611 19612 19613 19614 19615 19616 19617 19618 19619 19620 19621 19622 19623 19624 19625 19626 19627 19628 19629 19630 19631 19632 19633 19634 19635 19636 19637 19638 19639 19640 19641 19642 19643 19644 19645 19646 19647 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19610
SWIGINTERN VALUE
_wrap_DateTime_setSecond(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
int arg2 ;
void *argp1 = 0 ;
int res1 = 0 ;
int val2 ;
int ecode2 = 0 ;
if ((argc < 1) || (argc > 1)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","setSecond", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
ecode2 = SWIG_AsVal_int(argv[0], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","setSecond", 2, argv[0] ));
}
arg2 = static_cast< int >(val2);
{
if(tryRubyException([&]() mutable
{
(arg1)->setSecond(arg2);
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
return Qnil;
fail:
return Qnil;
}
|
#setYMD(*args) ⇒ Object
19245 19246 19247 19248 19249 19250 19251 19252 19253 19254 19255 19256 19257 19258 19259 19260 19261 19262 19263 19264 19265 19266 19267 19268 19269 19270 19271 19272 19273 19274 19275 19276 19277 19278 19279 19280 19281 19282 19283 19284 19285 19286 19287 19288 19289 19290 19291 19292 19293 19294 19295 19296 19297 19298 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 19245
SWIGINTERN VALUE
_wrap_DateTime_setYMD(int argc, VALUE *argv, VALUE self) {
FIX::DateTime *arg1 = (FIX::DateTime *) 0 ;
int arg2 ;
int arg3 ;
int arg4 ;
void *argp1 = 0 ;
int res1 = 0 ;
int val2 ;
int ecode2 = 0 ;
int val3 ;
int ecode3 = 0 ;
int val4 ;
int ecode4 = 0 ;
if ((argc < 3) || (argc > 3)) {
rb_raise(rb_eArgError, "wrong # of arguments(%d for 3)",argc); SWIG_fail;
}
res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__DateTime, 0 | 0 );
if (!SWIG_IsOK(res1)) {
SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::DateTime *","setYMD", 1, self ));
}
arg1 = reinterpret_cast< FIX::DateTime * >(argp1);
ecode2 = SWIG_AsVal_int(argv[0], &val2);
if (!SWIG_IsOK(ecode2)) {
SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","setYMD", 2, argv[0] ));
}
arg2 = static_cast< int >(val2);
ecode3 = SWIG_AsVal_int(argv[1], &val3);
if (!SWIG_IsOK(ecode3)) {
SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "int","setYMD", 3, argv[1] ));
}
arg3 = static_cast< int >(val3);
ecode4 = SWIG_AsVal_int(argv[2], &val4);
if (!SWIG_IsOK(ecode4)) {
SWIG_exception_fail(SWIG_ArgError(ecode4), Ruby_Format_TypeError( "", "int","setYMD", 4, argv[2] ));
}
arg4 = static_cast< int >(val4);
{
if(tryRubyException([&]() mutable
{
(arg1)->setYMD(arg2,arg3,arg4);
return self;
fail:
return Qnil;
}) == Qnil)
{
SWIG_fail;
}
}
return Qnil;
fail:
return Qnil;
}
|