Class: Quickfix::FieldMap
- Inherits:
-
Object
- Object
- Quickfix::FieldMap
- Defined in:
- ext/quickfix/QuickfixRuby.cpp
Instance Method Summary collapse
- #addGroup(*args, self) ⇒ Object
- #addGroupPtr(*args, self) ⇒ Object
-
#begin(*args, self) ⇒ Object
call-seq: begin -> FIX::FieldMap::iterator begin -> FIX::FieldMap::const_iterator.
- #calculateLength(*args, self) ⇒ Object
- #calculateString(*args) ⇒ Object
- #calculateTotal(*args, self) ⇒ Object
-
#clear(*args) ⇒ Object
call-seq: clear.
-
#end(*args, self) ⇒ Object
call-seq: end -> FIX::FieldMap::iterator end -> FIX::FieldMap::const_iterator.
- #g_begin(*args, self) ⇒ Object
- #g_end(*args, self) ⇒ Object
- #getField(*args, self) ⇒ Object
- #getFieldIfSet(*args) ⇒ Object
- #getFieldPtr(*args) ⇒ Object
- #getFieldRef(*args) ⇒ Object
- #getGroup(*args) ⇒ Object
- #getGroupPtr(*args) ⇒ Object
- #getGroupRef(*args) ⇒ Object
- #groupCount(*args) ⇒ Object
- #groups(*args) ⇒ Object
- #hasGroup(*args, self) ⇒ Object
- #initialize(*args, self) ⇒ Object constructor
- #isEmpty(*args) ⇒ Object
- #isSetField(*args, self) ⇒ Object
- #removeField(*args) ⇒ Object
- #removeGroup(*args, self) ⇒ Object
- #replaceGroup(*args) ⇒ Object
- #setField(*args, self) ⇒ Object
- #totalFields(*args) ⇒ Object
Constructor Details
#initialize(*args, self) ⇒ Object
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 31632 31633 31634 31635 31636 31637 31638 31639 31640 31641 31642 31643 31644 31645 31646 31647 31648 31649 31650 31651 31652 31653 31654 31655 31656 31657 31658 31659 31660 31661 31662 31663 31664 31665 31666 31667 31668 31669 31670 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 31611 SWIGINTERN VALUE _wrap_new_FieldMap(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[1]; int ii; argc = nargs; if (argc > 1) SWIG_fail; for (ii = 0; (ii < argc); ++ii) { argv[ii] = args[ii]; } if (argc == 0) { return _wrap_new_FieldMap__SWIG_2(nargs, args, self); } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, , SWIG_POINTER_NO_NULL); _v = SWIG_CheckState(res); if (_v) { return _wrap_new_FieldMap__SWIG_1(nargs, args, self); } } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0); _v = SWIG_CheckState(res); if (_v) { return _wrap_new_FieldMap__SWIG_3(nargs, args, self); } } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, SWIG_POINTER_NO_NULL); _v = SWIG_CheckState(res); if (_v) { return _wrap_new_FieldMap__SWIG_4(nargs, args, self); } } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, SWIG_POINTER_NO_NULL); _v = SWIG_CheckState(res); if (_v) { return _wrap_new_FieldMap__SWIG_5(nargs, args, self); } } fail: Ruby_Format_OverloadedError( argc, 1, "FieldMap.new", " FieldMap.new(message_order const &order)\n" " FieldMap.new()\n" " FieldMap.new(int const order[])\n" " FieldMap.new(FIX::FieldMap const ©)\n" " FieldMap.new(FIX::FieldMap &&rhs)\n"); return Qnil; } |
Instance Method Details
#addGroup(*args, self) ⇒ Object
32471 32472 32473 32474 32475 32476 32477 32478 32479 32480 32481 32482 32483 32484 32485 32486 32487 32488 32489 32490 32491 32492 32493 32494 32495 32496 32497 32498 32499 32500 32501 32502 32503 32504 32505 32506 32507 32508 32509 32510 32511 32512 32513 32514 32515 32516 32517 32518 32519 32520 32521 32522 32523 32524 32525 32526 32527 32528 32529 32530 32531 32532 32533 32534 32535 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 32471 SWIGINTERN VALUE _wrap_FieldMap_addGroup(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[5]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 5) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 3) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { void *vptr = 0; int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_FIX__FieldMap, SWIG_POINTER_NO_NULL); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_addGroup__SWIG_1(nargs, args, self); } } } } if (argc == 4) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { void *vptr = 0; int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_FIX__FieldMap, SWIG_POINTER_NO_NULL); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_bool(argv[3], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_addGroup__SWIG_0(nargs, args, self); } } } } } fail: Ruby_Format_OverloadedError( argc, 5, "FieldMap.addGroup", " void FieldMap.addGroup(int tag, FIX::FieldMap const &group, bool setCount)\n" " void FieldMap.addGroup(int tag, FIX::FieldMap const &group)\n"); return Qnil; } |
#addGroupPtr(*args, self) ⇒ Object
32642 32643 32644 32645 32646 32647 32648 32649 32650 32651 32652 32653 32654 32655 32656 32657 32658 32659 32660 32661 32662 32663 32664 32665 32666 32667 32668 32669 32670 32671 32672 32673 32674 32675 32676 32677 32678 32679 32680 32681 32682 32683 32684 32685 32686 32687 32688 32689 32690 32691 32692 32693 32694 32695 32696 32697 32698 32699 32700 32701 32702 32703 32704 32705 32706 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 32642 SWIGINTERN VALUE _wrap_FieldMap_addGroupPtr(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[5]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 5) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 3) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { void *vptr = 0; int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_addGroupPtr__SWIG_1(nargs, args, self); } } } } if (argc == 4) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { void *vptr = 0; int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_bool(argv[3], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_addGroupPtr__SWIG_0(nargs, args, self); } } } } } fail: Ruby_Format_OverloadedError( argc, 5, "FieldMap.addGroupPtr", " void FieldMap.addGroupPtr(int tag, FIX::FieldMap *group, bool setCount)\n" " void FieldMap.addGroupPtr(int tag, FIX::FieldMap *group)\n"); return Qnil; } |
#begin(*args, self) ⇒ Object
call-seq:
begin -> FIX::FieldMap::iterator
begin -> FIX::FieldMap::const_iterator
Return an iterator to the beginning of the FieldMap.
34002 34003 34004 34005 34006 34007 34008 34009 34010 34011 34012 34013 34014 34015 34016 34017 34018 34019 34020 34021 34022 34023 34024 34025 34026 34027 34028 34029 34030 34031 34032 34033 34034 34035 34036 34037 34038 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 34002 SWIGINTERN VALUE _wrap_FieldMap_begin(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[2]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 2) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_begin__SWIG_0(nargs, args, self); } } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_begin__SWIG_1(nargs, args, self); } } fail: Ruby_Format_OverloadedError( argc, 2, "FieldMap.begin", " FIX::FieldMap::iterator FieldMap.begin()\n" " FIX::FieldMap::const_iterator FieldMap.begin()\n"); return Qnil; } |
#calculateLength(*args, self) ⇒ Object
33652 33653 33654 33655 33656 33657 33658 33659 33660 33661 33662 33663 33664 33665 33666 33667 33668 33669 33670 33671 33672 33673 33674 33675 33676 33677 33678 33679 33680 33681 33682 33683 33684 33685 33686 33687 33688 33689 33690 33691 33692 33693 33694 33695 33696 33697 33698 33699 33700 33701 33702 33703 33704 33705 33706 33707 33708 33709 33710 33711 33712 33713 33714 33715 33716 33717 33718 33719 33720 33721 33722 33723 33724 33725 33726 33727 33728 33729 33730 33731 33732 33733 33734 33735 33736 33737 33738 33739 33740 33741 33742 33743 33744 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 33652 SWIGINTERN VALUE _wrap_FieldMap_calculateLength(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[5]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 5) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_calculateLength__SWIG_3(nargs, args, self); } } if (argc == 2) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_calculateLength__SWIG_2(nargs, args, self); } } } if (argc == 3) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { { int res = SWIG_AsVal_int(argv[2], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_calculateLength__SWIG_1(nargs, args, self); } } } } if (argc == 4) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { { int res = SWIG_AsVal_int(argv[2], NULL); _v = SWIG_CheckState(res); } if (_v) { { int res = SWIG_AsVal_int(argv[3], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_calculateLength__SWIG_0(nargs, args, self); } } } } } fail: Ruby_Format_OverloadedError( argc, 5, "FieldMap.calculateLength", " int FieldMap.calculateLength(int beginStringField, int bodyLengthField, int checkSumField)\n" " int FieldMap.calculateLength(int beginStringField, int bodyLengthField)\n" " int FieldMap.calculateLength(int beginStringField)\n" " int FieldMap.calculateLength()\n"); return Qnil; } |
#calculateString(*args) ⇒ Object
33416 33417 33418 33419 33420 33421 33422 33423 33424 33425 33426 33427 33428 33429 33430 33431 33432 33433 33434 33435 33436 33437 33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 33455 33456 33457 33458 33459 33460 33461 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 33416 SWIGINTERN VALUE _wrap_FieldMap_calculateString(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; std::string *arg2 = 0 ; void *argp1 = 0 ; int res1 = 0 ; std::string temp2 ; std::string *result = 0 ; VALUE vresult = Qnil; if ((argc < 1) || (argc > 1)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap const *","calculateString", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); { temp2 = std::string((char*)StringValuePtr(argv[0])); arg2 = &temp2; } { if(tryRubyException([&]() mutable { result = (std::string *) &((FIX::FieldMap const *)arg1)->calculateString(*arg2); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__string, 0 | 0 ); { if( std::string("std::string &") == "std::string &" ) { rb_str_resize( argv[0], 0 ); rb_str_append( argv[0], rb_str_new2(arg2->c_str()) ); } } return vresult; fail: return Qnil; } |
#calculateTotal(*args, self) ⇒ Object
33825 33826 33827 33828 33829 33830 33831 33832 33833 33834 33835 33836 33837 33838 33839 33840 33841 33842 33843 33844 33845 33846 33847 33848 33849 33850 33851 33852 33853 33854 33855 33856 33857 33858 33859 33860 33861 33862 33863 33864 33865 33866 33867 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 33825 SWIGINTERN VALUE _wrap_FieldMap_calculateTotal(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[3]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 3) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_calculateTotal__SWIG_1(nargs, args, self); } } if (argc == 2) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_calculateTotal__SWIG_0(nargs, args, self); } } } fail: Ruby_Format_OverloadedError( argc, 3, "FieldMap.calculateTotal", " int FieldMap.calculateTotal(int checkSumField)\n" " int FieldMap.calculateTotal()\n"); return Qnil; } |
#clear(*args) ⇒ Object
call-seq:
clear
Clear FieldMap contents.
33314 33315 33316 33317 33318 33319 33320 33321 33322 33323 33324 33325 33326 33327 33328 33329 33330 33331 33332 33333 33334 33335 33336 33337 33338 33339 33340 33341 33342 33343 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 33314 SWIGINTERN VALUE _wrap_FieldMap_clear(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; void *argp1 = 0 ; int res1 = 0 ; if ((argc < 0) || (argc > 0)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap *","clear", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); { if(tryRubyException([&]() mutable { (arg1)->clear(); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } return Qnil; fail: return Qnil; } |
#end(*args, self) ⇒ Object
call-seq:
end -> FIX::FieldMap::iterator
end -> FIX::FieldMap::const_iterator
Return an iterator to past the end of the FieldMap.
34085 34086 34087 34088 34089 34090 34091 34092 34093 34094 34095 34096 34097 34098 34099 34100 34101 34102 34103 34104 34105 34106 34107 34108 34109 34110 34111 34112 34113 34114 34115 34116 34117 34118 34119 34120 34121 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 34085 SWIGINTERN VALUE _wrap_FieldMap_end(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[2]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 2) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_end__SWIG_0(nargs, args, self); } } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_end__SWIG_1(nargs, args, self); } } fail: Ruby_Format_OverloadedError( argc, 2, "FieldMap.end", " FIX::FieldMap::iterator FieldMap.end()\n" " FIX::FieldMap::const_iterator FieldMap.end()\n"); return Qnil; } |
#g_begin(*args, self) ⇒ Object
34229 34230 34231 34232 34233 34234 34235 34236 34237 34238 34239 34240 34241 34242 34243 34244 34245 34246 34247 34248 34249 34250 34251 34252 34253 34254 34255 34256 34257 34258 34259 34260 34261 34262 34263 34264 34265 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 34229 SWIGINTERN VALUE _wrap_FieldMap_g_begin(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[2]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 2) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_g_begin__SWIG_0(nargs, args, self); } } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_g_begin__SWIG_1(nargs, args, self); } } fail: Ruby_Format_OverloadedError( argc, 2, "FieldMap.g_begin", " FIX::FieldMap::g_iterator FieldMap.g_begin()\n" " FIX::FieldMap::g_const_iterator FieldMap.g_begin()\n"); return Qnil; } |
#g_end(*args, self) ⇒ Object
34303 34304 34305 34306 34307 34308 34309 34310 34311 34312 34313 34314 34315 34316 34317 34318 34319 34320 34321 34322 34323 34324 34325 34326 34327 34328 34329 34330 34331 34332 34333 34334 34335 34336 34337 34338 34339 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 34303 SWIGINTERN VALUE _wrap_FieldMap_g_end(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[2]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 2) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_g_end__SWIG_0(nargs, args, self); } } if (argc == 1) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_g_end__SWIG_1(nargs, args, self); } } fail: Ruby_Format_OverloadedError( argc, 2, "FieldMap.g_end", " FIX::FieldMap::g_iterator FieldMap.g_end()\n" " FIX::FieldMap::g_const_iterator FieldMap.g_end()\n"); return Qnil; } |
#getField(*args, self) ⇒ Object
32046 32047 32048 32049 32050 32051 32052 32053 32054 32055 32056 32057 32058 32059 32060 32061 32062 32063 32064 32065 32066 32067 32068 32069 32070 32071 32072 32073 32074 32075 32076 32077 32078 32079 32080 32081 32082 32083 32084 32085 32086 32087 32088 32089 32090 32091 32092 32093 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 32046 SWIGINTERN VALUE _wrap_FieldMap_getField(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[3]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 3) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 2) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { void *vptr = 0; int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_FIX__FieldBase, SWIG_POINTER_NO_NULL); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_getField__SWIG_0(nargs, args, self); } } } if (argc == 2) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_getField__SWIG_1(nargs, args, self); } } } fail: Ruby_Format_OverloadedError( argc, 3, "FieldMap.getField", " FIX::FieldBase FieldMap.getField(FIX::FieldBase &field)\n" " std::string const & FieldMap.getField(int tag)\n"); return Qnil; } |
#getFieldIfSet(*args) ⇒ Object
31911 31912 31913 31914 31915 31916 31917 31918 31919 31920 31921 31922 31923 31924 31925 31926 31927 31928 31929 31930 31931 31932 31933 31934 31935 31936 31937 31938 31939 31940 31941 31942 31943 31944 31945 31946 31947 31948 31949 31950 31951 31952 31953 31954 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 31911 SWIGINTERN VALUE _wrap_FieldMap_getFieldIfSet(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; FIX::FieldBase *arg2 = 0 ; void *argp1 = 0 ; int res1 = 0 ; void *argp2 = 0 ; int res2 = 0 ; bool result; VALUE vresult = Qnil; if ((argc < 1) || (argc > 1)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap const *","getFieldIfSet", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); res2 = SWIG_ConvertPtr(argv[0], &argp2, SWIGTYPE_p_FIX__FieldBase, 0 ); if (!SWIG_IsOK(res2)) { SWIG_exception_fail(SWIG_ArgError(res2), Ruby_Format_TypeError( "", "FIX::FieldBase &","getFieldIfSet", 2, argv[0] )); } if (!argp2) { SWIG_exception_fail(SWIG_ValueError, Ruby_Format_TypeError("invalid null reference ", "FIX::FieldBase &","getFieldIfSet", 2, argv[0])); } arg2 = reinterpret_cast< FIX::FieldBase * >(argp2); { if(tryRubyException([&]() mutable { result = (bool)((FIX::FieldMap const *)arg1)->getFieldIfSet(*arg2); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } vresult = SWIG_From_bool(static_cast< bool >(result)); return vresult; fail: return Qnil; } |
#getFieldPtr(*args) ⇒ Object
32139 32140 32141 32142 32143 32144 32145 32146 32147 32148 32149 32150 32151 32152 32153 32154 32155 32156 32157 32158 32159 32160 32161 32162 32163 32164 32165 32166 32167 32168 32169 32170 32171 32172 32173 32174 32175 32176 32177 32178 32179 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 32139 SWIGINTERN VALUE _wrap_FieldMap_getFieldPtr(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; int arg2 ; void *argp1 = 0 ; int res1 = 0 ; int val2 ; int ecode2 = 0 ; FIX::FieldBase *result = 0 ; VALUE vresult = Qnil; if ((argc < 1) || (argc > 1)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap const *","getFieldPtr", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); ecode2 = SWIG_AsVal_int(argv[0], &val2); if (!SWIG_IsOK(ecode2)) { SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","getFieldPtr", 2, argv[0] )); } arg2 = static_cast< int >(val2); { if(tryRubyException([&]() mutable { result = (FIX::FieldBase *)((FIX::FieldMap const *)arg1)->getFieldPtr(arg2); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_FIX__FieldBase, 0 | 0 ); return vresult; fail: return Qnil; } |
#getFieldRef(*args) ⇒ Object
32096 32097 32098 32099 32100 32101 32102 32103 32104 32105 32106 32107 32108 32109 32110 32111 32112 32113 32114 32115 32116 32117 32118 32119 32120 32121 32122 32123 32124 32125 32126 32127 32128 32129 32130 32131 32132 32133 32134 32135 32136 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 32096 SWIGINTERN VALUE _wrap_FieldMap_getFieldRef(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; int arg2 ; void *argp1 = 0 ; int res1 = 0 ; int val2 ; int ecode2 = 0 ; FIX::FieldBase *result = 0 ; VALUE vresult = Qnil; if ((argc < 1) || (argc > 1)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap const *","getFieldRef", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); ecode2 = SWIG_AsVal_int(argv[0], &val2); if (!SWIG_IsOK(ecode2)) { SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","getFieldRef", 2, argv[0] )); } arg2 = static_cast< int >(val2); { if(tryRubyException([&]() mutable { result = (FIX::FieldBase *) &((FIX::FieldMap const *)arg1)->getFieldRef(arg2); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_FIX__FieldBase, 0 | 0 ); return vresult; fail: return Qnil; } |
#getGroup(*args) ⇒ Object
32768 32769 32770 32771 32772 32773 32774 32775 32776 32777 32778 32779 32780 32781 32782 32783 32784 32785 32786 32787 32788 32789 32790 32791 32792 32793 32794 32795 32796 32797 32798 32799 32800 32801 32802 32803 32804 32805 32806 32807 32808 32809 32810 32811 32812 32813 32814 32815 32816 32817 32818 32819 32820 32821 32822 32823 32824 32825 32826 32827 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 32768 SWIGINTERN VALUE _wrap_FieldMap_getGroup(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; int arg2 ; int arg3 ; FIX::FieldMap *arg4 = 0 ; void *argp1 = 0 ; int res1 = 0 ; int val2 ; int ecode2 = 0 ; int val3 ; int ecode3 = 0 ; void *argp4 = 0 ; int res4 = 0 ; FIX::FieldMap *result = 0 ; VALUE vresult = Qnil; if ((argc < 3) || (argc > 3)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 3)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap const *","getGroup", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); ecode2 = SWIG_AsVal_int(argv[0], &val2); if (!SWIG_IsOK(ecode2)) { SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","getGroup", 2, argv[0] )); } arg2 = static_cast< int >(val2); ecode3 = SWIG_AsVal_int(argv[1], &val3); if (!SWIG_IsOK(ecode3)) { SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "int","getGroup", 3, argv[1] )); } arg3 = static_cast< int >(val3); res4 = SWIG_ConvertPtr(argv[2], &argp4, SWIGTYPE_p_FIX__FieldMap, 0 ); if (!SWIG_IsOK(res4)) { SWIG_exception_fail(SWIG_ArgError(res4), Ruby_Format_TypeError( "", "FIX::FieldMap &","getGroup", 4, argv[2] )); } if (!argp4) { SWIG_exception_fail(SWIG_ValueError, Ruby_Format_TypeError("invalid null reference ", "FIX::FieldMap &","getGroup", 4, argv[2])); } arg4 = reinterpret_cast< FIX::FieldMap * >(argp4); { if(tryRubyException([&]() mutable { result = (FIX::FieldMap *) &((FIX::FieldMap const *)arg1)->getGroup(arg2,arg3,*arg4); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); return vresult; fail: return Qnil; } |
#getGroupPtr(*args) ⇒ Object
32881 32882 32883 32884 32885 32886 32887 32888 32889 32890 32891 32892 32893 32894 32895 32896 32897 32898 32899 32900 32901 32902 32903 32904 32905 32906 32907 32908 32909 32910 32911 32912 32913 32914 32915 32916 32917 32918 32919 32920 32921 32922 32923 32924 32925 32926 32927 32928 32929 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 32881 SWIGINTERN VALUE _wrap_FieldMap_getGroupPtr(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; int arg2 ; int arg3 ; void *argp1 = 0 ; int res1 = 0 ; int val2 ; int ecode2 = 0 ; int val3 ; int ecode3 = 0 ; FIX::FieldMap *result = 0 ; VALUE vresult = Qnil; if ((argc < 2) || (argc > 2)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap const *","getGroupPtr", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); ecode2 = SWIG_AsVal_int(argv[0], &val2); if (!SWIG_IsOK(ecode2)) { SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","getGroupPtr", 2, argv[0] )); } arg2 = static_cast< int >(val2); ecode3 = SWIG_AsVal_int(argv[1], &val3); if (!SWIG_IsOK(ecode3)) { SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "int","getGroupPtr", 3, argv[1] )); } arg3 = static_cast< int >(val3); { if(tryRubyException([&]() mutable { result = (FIX::FieldMap *)((FIX::FieldMap const *)arg1)->getGroupPtr(arg2,arg3); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); return vresult; fail: return Qnil; } |
#getGroupRef(*args) ⇒ Object
32830 32831 32832 32833 32834 32835 32836 32837 32838 32839 32840 32841 32842 32843 32844 32845 32846 32847 32848 32849 32850 32851 32852 32853 32854 32855 32856 32857 32858 32859 32860 32861 32862 32863 32864 32865 32866 32867 32868 32869 32870 32871 32872 32873 32874 32875 32876 32877 32878 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 32830 SWIGINTERN VALUE _wrap_FieldMap_getGroupRef(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; int arg2 ; int arg3 ; void *argp1 = 0 ; int res1 = 0 ; int val2 ; int ecode2 = 0 ; int val3 ; int ecode3 = 0 ; FIX::FieldMap *result = 0 ; VALUE vresult = Qnil; if ((argc < 2) || (argc > 2)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap const *","getGroupRef", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); ecode2 = SWIG_AsVal_int(argv[0], &val2); if (!SWIG_IsOK(ecode2)) { SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","getGroupRef", 2, argv[0] )); } arg2 = static_cast< int >(val2); ecode3 = SWIG_AsVal_int(argv[1], &val3); if (!SWIG_IsOK(ecode3)) { SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "int","getGroupRef", 3, argv[1] )); } arg3 = static_cast< int >(val3); { if(tryRubyException([&]() mutable { result = (FIX::FieldMap *) &((FIX::FieldMap const *)arg1)->getGroupRef(arg2,arg3); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); return vresult; fail: return Qnil; } |
#groupCount(*args) ⇒ Object
33263 33264 33265 33266 33267 33268 33269 33270 33271 33272 33273 33274 33275 33276 33277 33278 33279 33280 33281 33282 33283 33284 33285 33286 33287 33288 33289 33290 33291 33292 33293 33294 33295 33296 33297 33298 33299 33300 33301 33302 33303 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 33263 SWIGINTERN VALUE _wrap_FieldMap_groupCount(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; int arg2 ; void *argp1 = 0 ; int res1 = 0 ; int val2 ; int ecode2 = 0 ; size_t result; VALUE vresult = Qnil; if ((argc < 1) || (argc > 1)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap const *","groupCount", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); ecode2 = SWIG_AsVal_int(argv[0], &val2); if (!SWIG_IsOK(ecode2)) { SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","groupCount", 2, argv[0] )); } arg2 = static_cast< int >(val2); { if(tryRubyException([&]() mutable { result = ((FIX::FieldMap const *)arg1)->groupCount(arg2); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } vresult = SWIG_From_size_t(static_cast< size_t >(result)); return vresult; fail: return Qnil; } |
#groups(*args) ⇒ Object
32932 32933 32934 32935 32936 32937 32938 32939 32940 32941 32942 32943 32944 32945 32946 32947 32948 32949 32950 32951 32952 32953 32954 32955 32956 32957 32958 32959 32960 32961 32962 32963 32964 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 32932 SWIGINTERN VALUE _wrap_FieldMap_groups(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; void *argp1 = 0 ; int res1 = 0 ; FIX::FieldMap::Groups *result = 0 ; VALUE vresult = Qnil; if ((argc < 0) || (argc > 0)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap const *","groups", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); { if(tryRubyException([&]() mutable { result = (FIX::FieldMap::Groups *) &((FIX::FieldMap const *)arg1)->groups(); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__mapT_int_std__vectorT_FIX__FieldMap_p_std__allocatorT_FIX__FieldMap_p_t_t_std__lessT_int_t_ALLOCATORT_std__pairT_int_const_std__vectorT_FIX__FieldMap_p_std__allocatorT_FIX__FieldMap_p_t_t_t_t_t, 0 | 0 ); return vresult; fail: return Qnil; } |
#hasGroup(*args, self) ⇒ Object
33206 33207 33208 33209 33210 33211 33212 33213 33214 33215 33216 33217 33218 33219 33220 33221 33222 33223 33224 33225 33226 33227 33228 33229 33230 33231 33232 33233 33234 33235 33236 33237 33238 33239 33240 33241 33242 33243 33244 33245 33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 33259 33260 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 33206 SWIGINTERN VALUE _wrap_FieldMap_hasGroup(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[4]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 4) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 2) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_hasGroup__SWIG_0(nargs, args, self); } } } if (argc == 3) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { { int res = SWIG_AsVal_int(argv[2], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_hasGroup__SWIG_1(nargs, args, self); } } } } fail: Ruby_Format_OverloadedError( argc, 4, "FieldMap.hasGroup", " bool FieldMap.hasGroup(int tag)\n" " bool FieldMap.hasGroup(int num, int tag)\n"); return Qnil; } |
#isEmpty(*args) ⇒ Object
33346 33347 33348 33349 33350 33351 33352 33353 33354 33355 33356 33357 33358 33359 33360 33361 33362 33363 33364 33365 33366 33367 33368 33369 33370 33371 33372 33373 33374 33375 33376 33377 33378 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 33346 SWIGINTERN VALUE _wrap_FieldMap_isEmpty(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; void *argp1 = 0 ; int res1 = 0 ; bool result; VALUE vresult = Qnil; if ((argc < 0) || (argc > 0)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap *","isEmpty", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); { if(tryRubyException([&]() mutable { result = (bool)(arg1)->isEmpty(); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } vresult = SWIG_From_bool(static_cast< bool >(result)); return vresult; fail: return Qnil; } |
#isSetField(*args, self) ⇒ Object
32271 32272 32273 32274 32275 32276 32277 32278 32279 32280 32281 32282 32283 32284 32285 32286 32287 32288 32289 32290 32291 32292 32293 32294 32295 32296 32297 32298 32299 32300 32301 32302 32303 32304 32305 32306 32307 32308 32309 32310 32311 32312 32313 32314 32315 32316 32317 32318 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 32271 SWIGINTERN VALUE _wrap_FieldMap_isSetField(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[3]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 3) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 2) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { void *vptr = 0; int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_FIX__FieldBase, SWIG_POINTER_NO_NULL); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_isSetField__SWIG_0(nargs, args, self); } } } if (argc == 2) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_isSetField__SWIG_1(nargs, args, self); } } } fail: Ruby_Format_OverloadedError( argc, 3, "FieldMap.isSetField", " bool FieldMap.isSetField(FIX::FieldBase const &field)\n" " bool FieldMap.isSetField(int tag)\n"); return Qnil; } |
#removeField(*args) ⇒ Object
32321 32322 32323 32324 32325 32326 32327 32328 32329 32330 32331 32332 32333 32334 32335 32336 32337 32338 32339 32340 32341 32342 32343 32344 32345 32346 32347 32348 32349 32350 32351 32352 32353 32354 32355 32356 32357 32358 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 32321 SWIGINTERN VALUE _wrap_FieldMap_removeField(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; int arg2 ; void *argp1 = 0 ; int res1 = 0 ; int val2 ; int ecode2 = 0 ; if ((argc < 1) || (argc > 1)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap *","removeField", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); ecode2 = SWIG_AsVal_int(argv[0], &val2); if (!SWIG_IsOK(ecode2)) { SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","removeField", 2, argv[0] )); } arg2 = static_cast< int >(val2); { if(tryRubyException([&]() mutable { (arg1)->removeField(arg2); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } return Qnil; fail: return Qnil; } |
#removeGroup(*args, self) ⇒ Object
33055 33056 33057 33058 33059 33060 33061 33062 33063 33064 33065 33066 33067 33068 33069 33070 33071 33072 33073 33074 33075 33076 33077 33078 33079 33080 33081 33082 33083 33084 33085 33086 33087 33088 33089 33090 33091 33092 33093 33094 33095 33096 33097 33098 33099 33100 33101 33102 33103 33104 33105 33106 33107 33108 33109 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 33055 SWIGINTERN VALUE _wrap_FieldMap_removeGroup(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[4]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 4) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 2) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_removeGroup__SWIG_1(nargs, args, self); } } } if (argc == 3) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { { int res = SWIG_AsVal_int(argv[2], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_removeGroup__SWIG_0(nargs, args, self); } } } } fail: Ruby_Format_OverloadedError( argc, 4, "FieldMap.removeGroup", " void FieldMap.removeGroup(int num, int tag)\n" " void FieldMap.removeGroup(int tag)\n"); return Qnil; } |
#replaceGroup(*args) ⇒ Object
32709 32710 32711 32712 32713 32714 32715 32716 32717 32718 32719 32720 32721 32722 32723 32724 32725 32726 32727 32728 32729 32730 32731 32732 32733 32734 32735 32736 32737 32738 32739 32740 32741 32742 32743 32744 32745 32746 32747 32748 32749 32750 32751 32752 32753 32754 32755 32756 32757 32758 32759 32760 32761 32762 32763 32764 32765 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 32709 SWIGINTERN VALUE _wrap_FieldMap_replaceGroup(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; int arg2 ; int arg3 ; FIX::FieldMap *arg4 = 0 ; void *argp1 = 0 ; int res1 = 0 ; int val2 ; int ecode2 = 0 ; int val3 ; int ecode3 = 0 ; void *argp4 = 0 ; int res4 = 0 ; if ((argc < 3) || (argc > 3)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 3)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap *","replaceGroup", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); ecode2 = SWIG_AsVal_int(argv[0], &val2); if (!SWIG_IsOK(ecode2)) { SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","replaceGroup", 2, argv[0] )); } arg2 = static_cast< int >(val2); ecode3 = SWIG_AsVal_int(argv[1], &val3); if (!SWIG_IsOK(ecode3)) { SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "int","replaceGroup", 3, argv[1] )); } arg3 = static_cast< int >(val3); res4 = SWIG_ConvertPtr(argv[2], &argp4, SWIGTYPE_p_FIX__FieldMap, 0 ); if (!SWIG_IsOK(res4)) { SWIG_exception_fail(SWIG_ArgError(res4), Ruby_Format_TypeError( "", "FIX::FieldMap const &","replaceGroup", 4, argv[2] )); } if (!argp4) { SWIG_exception_fail(SWIG_ValueError, Ruby_Format_TypeError("invalid null reference ", "FIX::FieldMap const &","replaceGroup", 4, argv[2])); } arg4 = reinterpret_cast< FIX::FieldMap * >(argp4); { if(tryRubyException([&]() mutable { (arg1)->replaceGroup(arg2,arg3,(FIX::FieldMap const &)*arg4); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } return Qnil; fail: return Qnil; } |
#setField(*args, self) ⇒ Object
31836 31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 31854 31855 31856 31857 31858 31859 31860 31861 31862 31863 31864 31865 31866 31867 31868 31869 31870 31871 31872 31873 31874 31875 31876 31877 31878 31879 31880 31881 31882 31883 31884 31885 31886 31887 31888 31889 31890 31891 31892 31893 31894 31895 31896 31897 31898 31899 31900 31901 31902 31903 31904 31905 31906 31907 31908 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 31836 SWIGINTERN VALUE _wrap_FieldMap_setField(int nargs, VALUE *args, VALUE self) { int argc; VALUE argv[4]; int ii; argc = nargs + 1; argv[0] = self; if (argc > 4) SWIG_fail; for (ii = 1; (ii < argc); ++ii) { argv[ii] = args[ii-1]; } if (argc == 2) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { void *vptr = 0; int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_FIX__FieldBase, SWIG_POINTER_NO_NULL); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_setField__SWIG_1(nargs, args, self); } } } if (argc == 3) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { void *vptr = 0; int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_FIX__FieldBase, SWIG_POINTER_NO_NULL); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_bool(argv[2], NULL); _v = SWIG_CheckState(res); } if (_v) { return _wrap_FieldMap_setField__SWIG_0(nargs, args, self); } } } } if (argc == 3) { int _v = 0; void *vptr = 0; int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_FIX__FieldMap, 0); _v = SWIG_CheckState(res); if (_v) { { int res = SWIG_AsVal_int(argv[1], NULL); _v = SWIG_CheckState(res); } if (_v) { int res = SWIG_AsPtr_std_string(argv[2], (std::string**)(0)); _v = SWIG_CheckState(res); if (_v) { return _wrap_FieldMap_setField__SWIG_2(nargs, args, self); } } } } fail: Ruby_Format_OverloadedError( argc, 4, "FieldMap.setField", " void FieldMap.setField(FIX::FieldBase const &field, bool overwrite)\n" " void FieldMap.setField(FIX::FieldBase const &field)\n" " void FieldMap.setField(int tag, std::string const &value)\n"); return Qnil; } |
#totalFields(*args) ⇒ Object
33381 33382 33383 33384 33385 33386 33387 33388 33389 33390 33391 33392 33393 33394 33395 33396 33397 33398 33399 33400 33401 33402 33403 33404 33405 33406 33407 33408 33409 33410 33411 33412 33413 |
# File 'ext/quickfix/QuickfixRuby.cpp', line 33381 SWIGINTERN VALUE _wrap_FieldMap_totalFields(int argc, VALUE *argv, VALUE self) { FIX::FieldMap *arg1 = (FIX::FieldMap *) 0 ; void *argp1 = 0 ; int res1 = 0 ; size_t result; VALUE vresult = Qnil; if ((argc < 0) || (argc > 0)) { rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail; } res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_FIX__FieldMap, 0 | 0 ); if (!SWIG_IsOK(res1)) { SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "FIX::FieldMap const *","totalFields", 1, self )); } arg1 = reinterpret_cast< FIX::FieldMap * >(argp1); { if(tryRubyException([&]() mutable { result = ((FIX::FieldMap const *)arg1)->totalFields(); return self; fail: return Qnil; }) == Qnil) { SWIG_fail; } } vresult = SWIG_From_size_t(static_cast< size_t >(result)); return vresult; fail: return Qnil; } |